==> haskell-logging-facade-0.3.0-254-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logging-facade
version:              0.3.0
visibility:           public
id:                   logging-facade-0.3.0-A4OjaLn4dBgJh8i8LC0pg6
key:                  logging-facade-0.3.0-A4OjaLn4dBgJh8i8LC0pg6
license:              MIT
copyright:            (c) 2014-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  b7127a49ee5847c6f9e883ff5ad867ef
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.0.1/site-local/logging-facade-0.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/logging-facade-0.3.0
hs-libraries:         HSlogging-facade-0.3.0-A4OjaLn4dBgJh8i8LC0pg6
depends:
    base-4.15.0.0 call-stack-0.4.0-8Okwb0cowpe8mB1pBLnCB
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logging-facade-0.3.0-256-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logging-facade.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logging-facade
version:              0.3.0
visibility:           public
id:                   logging-facade-0.3.0-6hYGzVkxWWwKfx8h5jDmhM
key:                  logging-facade-0.3.0-6hYGzVkxWWwKfx8h5jDmhM
license:              MIT
copyright:            (c) 2014-2017 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/logging-facade#readme
synopsis:             Simple logging abstraction that allows multiple back-ends
description:          Simple logging abstraction that allows multiple back-ends
category:             System
abi:                  f0e901d7fdc2a48b2e419fd04054c978
exposed:              True
exposed-modules:
    System.Logging.Facade System.Logging.Facade.Class
    System.Logging.Facade.Sink System.Logging.Facade.Types

hidden-modules:       Paths_logging_facade
import-dirs:          /usr/lib/ghc-9.0.1/site-local/logging-facade-0.3.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/logging-facade-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/logging-facade-0.3.0
hs-libraries:         HSlogging-facade-0.3.0-6hYGzVkxWWwKfx8h5jDmhM
depends:
    base-4.15.0.0 call-stack-0.4.0-8Okwb0cowpe8mB1pBLnCB
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-logging-facade/html/logging-facade.haddock

haddock-html:         /usr/share/doc/haskell-logging-facade/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
